@@ -10,7 +10,8 @@ SK.nest.default <- function(x,
                             error,
                             fl1,
                             fl2=0,
-                            sig.level=.05, ...)
+                            sig.level=.05,
+                            dispersion=c('mm', 's', 'se'), ...)
 { 
   if (is.data.frame(y))
     y <- as.matrix(y[, 1])  # manova is not contemplated
@@ -19,19 +20,24 @@ SK.nest.default <- function(x,
 
   if (is.matrix(x) || is.atomic(x))
     x <- as.data.frame(x)
+
   if(!is.null(y))
     dat <- as.data.frame(cbind(x, y))
   else
     dat <- x
 
-  av <- eval(substitute(aov(fo, x), list(fo=formula(model))))
+  av <- eval(substitute(aov(fo,
+                            x),
+                        list(fo=formula(model))))
+
   if(class(av)[1] == 'aov')
     res <- SK.nest.aov(x=av,
                        which=which,
                        id.trim=id.trim,
                        fl1=fl1,
                        fl2=fl2,
-                       sig.level=sig.level)
+                       sig.level=sig.level,
+                       dispersion=dispersion)
   else
     res <- SK.nest.aovlist(x=av,
                            which=which,
@@ -39,6 +45,8 @@ SK.nest.default <- function(x,
                            error=error,
                            fl1=fl1,
                            fl2=fl2,
-                           sig.level=sig.level)
+                           sig.level=sig.level,
+                           dispersion=dispersion)
+
   invisible(res)
 }
