@@ -4,9 +4,12 @@
 
 summary.SK.nest <- function(object, ...)
 {
-  if(!inherits(object, 'SK.nest'))
+  if(!inherits(object,
+               'SK.nest'))
     stop("Use only with \"SK.nest\" objects!")
+
   ngroups <- object$groups[length(object$groups)]
+
   if(ngroups > 26)
     groupletter <- as.vector(t(outer(letters,
                                      letters,
@@ -14,19 +17,24 @@ summary.SK.nest <- function(object, ...)
                                      sep="")))             
   else
     groupletter <- letters
+
   xgroups <- seq(ngroups)
+
   for(i in 1 : ngroups)
     object$groups[object$groups == xgroups[i]] <- groupletter[i]
+
   out <- data.frame(rownames(object$m.inf),
                     object$m.inf[, 1],
                     object$groups)
+
   names(out) <- c('Levels',
                   'Means',
                   paste('SK(',
                         100*object$sig.level,
                         '%)',
                         sep=''))
-  if(class(object$av)[1]=='aovlist'){
+
+  if(class(object$av)[1]=='aovlist') {
     if(object$fl2 == 0){
       cat('Nested:',
           paste(names(dimnames(object$tab)[1]),
@@ -45,7 +53,7 @@ summary.SK.nest <- function(object, ...)
           '\n')
     }
   } else {
-    if(object$fl2 == 0){
+    if(object$fl2 == 0) {
       cat('Nested:',
           paste(names(dimnames(object$tab)[1]),
                 '/',
@@ -63,6 +71,7 @@ summary.SK.nest <- function(object, ...)
           '\n')
     }
   }
+
   print(out,
         row.names=FALSE)
 }
